# -*- coding: utf-8 -*-

import requests
import urllib

from django.urls import reverse


class RemoteTestMixin:
    # ROLE - superuser
    def v1_superuser_role_role_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:role-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_role_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_role_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:role-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_role_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_role_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:role-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    
    # USER ROLE - superuser
    def v1_superuser_role_user_role_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:userrole-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_user_role_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:userrole-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_user_role_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:userrole-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_user_role_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:userrole-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_user_role_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:userrole-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    
    # REQUIRED FIELD - superuser
    def v1_superuser_role_required_field_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:requiredfield-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_required_field_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:requiredfield-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_required_field_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:requiredfield-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_required_field_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:requiredfield-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_required_field_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:requiredfield-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    
    # STATUS FLOW - superuser
    def v1_superuser_role_status_flow_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:statusflow-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_status_flow_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:statusflow-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_status_flow_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:statusflow-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_status_flow_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:statusflow-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_status_flow_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:statusflow-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    
    # USED FIELD - superuser
    def v1_superuser_role_used_field_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:usedfield-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_used_field_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:usedfield-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_used_field_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:usedfield-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_used_field_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:usedfield-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_used_field_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:usedfield-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    
    # FILTER - superuser
    def v1_superuser_role_filter_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:filter-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_filter_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:filter-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_filter_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:filter-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_filter_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:filter-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_filter_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:filter-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp
    
    # MENU - superuser
    def v1_superuser_role_menu_list(self, filters=None):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:menu-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers, params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_role_menu_retrieve(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=headers)
        self.rprint(resp)
        return resp

    def v1_superuser_role_menu_create(self, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:menu-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_menu_update(self, pk, post_dict):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=headers, json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_role_menu_destroy(self, pk):
        self.token_refresh()
        headers = {'Authorization': 'JWT {}'.format(self.jwt)}
        endpoint = reverse(
            'api-v1-role:menu-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=headers)
        self.rprint(resp)
        return resp

    
